// ConfirmUnsavedDocumentDlg.h
// (c) 2003 exeal

#ifndef _CONFIRM_UNSAVED_DOCUMENT_DLG_H_
#define _CONFIRM_UNSAVED_DOCUMENT_DLG_H_
#include "..\Manah\Dialog.h"
#include "..\Manah\LinkLabel.h"
#include <vector>
using Manah::Windows::Controls::CDialog;
using Manah::Windows::Controls::CLinkLabel;


// CConfirmUnsavedDocumentDlg class definition
/////////////////////////////////////////////////////////////////////////////

namespace Alpha {

///	ۑ̃t@C
struct TDirtyFile {
	unsigned int	iTab;			//	^uԍ (_CAONX͎gpȂ)
	wstring			strFileName;	//	t@C
	bool			bSave;			//	ۑ邩ǂ
};

///	[ۑĂȂhLg] _CAO
class CConfirmUnsavedDocumentDlg : public CDialog {
	// bZ[Wnh
protected:
	bool	OnCommand(WORD wID, WORD wNotifyCode, HWND hwndCtrl);
	bool	OnInitDialog(HWND hwndFocus, LPARAM lInitParam);
	void	OnOK();

	// f[^o
public:
	vector<TDirtyFile>	m_vecFiles;
	CLinkLabel			m_oSelectAllLinkLabel;
	CLinkLabel			m_oClearAllLinkLabel;
};

}

#endif /* _CONFIRM_UNSAVED_DOCUMENT_DLG_H_ */

/* [EOF] */